@@ -100,7 +100,7 @@ class Contact(MWRAPBase):
         :type tags: list
 
         :returns: The created contact object
-        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
+        :rtype: :class:`moco_wrapper.util.response.ObjectResponse`
         """
 
         data = {
@@ -192,7 +192,7 @@ class Contact(MWRAPBase):
         :type tags: list
 
         :returns: The updated contact object
-        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
+        :rtype: :class:`moco_wrapper.util.response.ObjectResponse`
         """
 
         data = {}
@@ -235,7 +235,7 @@ class Contact(MWRAPBase):
         :type contact_id: int
 
         :returns: The contact object
-        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
+        :rtype: :class:`moco_wrapper.util.response.ObjectResponse`
         """
         return self._moco.get(API_PATH["contact_get"].format(id=contact_id))
 
@@ -267,7 +267,7 @@ class Contact(MWRAPBase):
         :type page: int
 
         :returns: List of contact objects
-        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
+        :rtype: :class:`moco_wrapper.util.response.PagedListResponse`
         """
         params = {}
         for key, value in (
