@@ -1,5 +1,6 @@
 from . import DefaultObjector
-from moco_wrapper.util.response import ListingResponse, JsonResponse
+from moco_wrapper.util.response import ObjectResponse, ListResponse, PagedListResponse
+
 
 class NoErrorObjector(DefaultObjector):
     """
@@ -30,13 +31,11 @@ class NoErrorObjector(DefaultObjector):
         :param requestor_response: response object (see :ref:`response`)
         :returns: modified response object
 
-        .. note:: only :class:`moco_wrapper.util.response.JsonResponse` and :class:`moco_wrapper.util.response.ListingResponse` are object to this conversion. Error responses will not be touched by this objector.
+        .. note:: only :class:`moco_wrapper.util.response.ObjectResponse` and :class:`moco_wrapper.util.response.PagedListResponse` are object to this conversion. Error responses will not be touched by this objector.
 
         .. note:: if the method :meth:`get_class_name_from_request_url` that is used to find the right class for conversion, returns ``None``, no conversion of objects will take place
         """
-        if isinstance(requestor_response, (JsonResponse, ListingResponse) ):
+        if isinstance(requestor_response, (ObjectResponse, ListResponse, PagedListResponse)):
             return super(NoErrorObjector, self).convert(requestor_response)
-        
 
         return requestor_response
-        
\ No newline at end of file
