@@ -1,30 +1,33 @@
 from moco_wrapper.models.comment import CommentTargetType
-from moco_wrapper.util.response import ListingResponse, JsonResponse, EmptyResponse
+from moco_wrapper.models.company import CompanyType
+from moco_wrapper.util.response import ObjectResponse, ListResponse, PagedListResponse, EmptyResponse
+
 
 from datetime import date
 
 from .. import IntegrationTest
 
+
 class TestComment(IntegrationTest):
     def get_user(self):
         with self.recorder.use_cassette("TestComment.get_user"):
             user = self.moco.User.getlist().items[0]
             return user
-    
+
     def get_customer(self):
         with self.recorder.use_cassette("TestComment.get_customer"):
             customer_create = self.moco.Company.create(
-                "TestComment", 
-                company_type="customer"
+                name="TestComment.get_customer",
+                company_type=CompanyType.CUSTOMER
             )
 
             return customer_create.data
 
-    def get_second_customer(self):
-        with self.recorder.use_cassette("TestComment.get_second_customer"):
+    def get_other_customer(self):
+        with self.recorder.use_cassette("TestComment.get_other_customer"):
             customer_create = self.moco.Company.create(
-                "TestComment second customer",
-                company_type="customer"
+                name="TestComment.get_other_customer",
+                company_type=CompanyType.CUSTOMER
             )
 
             return customer_create.data
@@ -35,10 +38,10 @@ class TestComment(IntegrationTest):
 
         with self.recorder.use_cassette("TestComment.get_project"):
             project_create = self.moco.Project.create(
-                "TestProjects for comments",
-                "EUR",
-                user.id,
-                customer.id,
+                name="TestComment.get_project",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=date(2020, 1, 1)
             )
 
@@ -49,8 +52,8 @@ class TestComment(IntegrationTest):
             comment_list = self.moco.Comment.getlist()
 
             assert comment_list.response.status_code == 200
-            
-            assert isinstance(comment_list, ListingResponse)
+
+            assert type(comment_list) is PagedListResponse
 
             assert comment_list.current_page == 1
             assert comment_list.is_last is not None
@@ -60,23 +63,25 @@ class TestComment(IntegrationTest):
 
     def test_get(self):
         project = self.get_project()
-        
+
         with self.recorder.use_cassette("TestComment.test_get"):
-            text = "test create comment"
+            text = "TestComment.test_get_create"
 
             comment_create = self.moco.Comment.create(
-                project.id, 
-                CommentTargetType.PROJECT, 
-                text,
+                commentable_id=project.id,
+                commentable_type=CommentTargetType.PROJECT,
+                text=text,
             )
 
-            comment_get = self.moco.Comment.get(comment_create.data.id)
+            comment_get = self.moco.Comment.get(
+                comment_id=comment_create.data.id
+            )
 
             assert comment_create.response.status_code == 200
             assert comment_get.response.status_code == 200
-            
-            assert isinstance(comment_create, JsonResponse)
-            assert isinstance(comment_get, JsonResponse)
+
+            assert type(comment_create) is ObjectResponse
+            assert type(comment_get) is ObjectResponse
 
             assert comment_get.data.text == text
             assert comment_get.data.commentable_id == project.id
@@ -87,69 +92,87 @@ class TestComment(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestComment.test_create"):
-            text = "test create comment"
+            text = "TestComment.test_create"
 
             comment_create = self.moco.Comment.create(
-                project.id, 
-                CommentTargetType.PROJECT, 
-                text,
+                commentable_id=project.id,
+                commentable_type=CommentTargetType.PROJECT,
+                text=text,
             )
 
             assert comment_create.response.status_code == 200
-            
-            assert isinstance(comment_create, JsonResponse)
+
+            assert type(comment_create) is ObjectResponse
 
             assert comment_create.data.text == text
             assert comment_create.data.commentable_id == project.id
             assert comment_create.data.commentable_type == CommentTargetType.PROJECT
             assert comment_create.data.user.id is not None
 
+    def test_create_company(self):
+        company = self.get_customer()
+
+        with self.recorder.use_cassette("TestComment.test_create_company"):
+            text = "TestComment.test_create_company"
+
+            comment_create = self.moco.Comment.create(
+                commentable_id=company.id,
+                commentable_type=CommentTargetType.COMPANY,
+                text=text
+            )
+
+            assert comment_create.response.status_code == 200
+
+            assert type(comment_create) is ObjectResponse
+
+            assert comment_create.data.text == text
+            assert comment_create.data.commentable_id == company.id
+            assert comment_create.data.commentable_type == CommentTargetType.COMPANY
+            assert comment_create.data.user.id is not None
+
     def test_create_bulk(self):
-        first_customer = self.get_customer()
-        second_customer = self.get_second_customer()
+        customer = self.get_customer()
+        other_customer = self.get_other_customer()
 
         with self.recorder.use_cassette("TestComment.test_create_bulk"):
-            text = "bulk comment creation"
-            comment_ids = [first_customer.id, second_customer.id]
-            comment_type = CommentTargetType.CUSTOMER
-            
+            text = "TestComment.test_create_bulk"
+            comment_ids = [customer.id, other_customer.id]
+            comment_type = CommentTargetType.COMPANY
+
             comment_create_bulk = self.moco.Comment.create_bulk(
-                comment_ids,
-                comment_type,
-                text,
+                commentable_ids=comment_ids,
+                commentable_type=comment_type,
+                text=text,
             )
 
             assert comment_create_bulk.response.status_code == 200
 
-            assert isinstance(comment_create_bulk, ListingResponse)
+            assert type(comment_create_bulk) is ListResponse
 
             assert len(comment_create_bulk.data) == len(comment_ids)
 
-
     def test_update(self):
         project = self.get_project()
-        user = self.get_user()
-
 
         with self.recorder.use_cassette("TestComment.test_update"):
-            update_text = "updated comment"
+            update_text = "TestComment.test_update"
 
             comment_create = self.moco.Comment.create(
-                project.id,
-                CommentTargetType.PROJECT,
-                "dummy comment, update comment"
+                commentable_id=project.id,
+                commentable_type=CommentTargetType.PROJECT,
+                text="TestComment.test_update_create"
             )
 
             comment_update = self.moco.Comment.update(
-                comment_create.data.id,
-                update_text
+                comment_id=comment_create.data.id,
+                text=update_text
             )
 
             assert comment_create.response.status_code == 200
             assert comment_update.response.status_code == 200
 
-            assert isinstance(comment_create, JsonResponse)
-            assert isinstance(comment_update, JsonResponse)
+            assert type(comment_create) is ObjectResponse
+            assert type(comment_update) is ObjectResponse
 
             assert comment_update.data.text == update_text
             assert comment_update.data.commentable_id == project.id
@@ -161,14 +184,15 @@ class TestComment(IntegrationTest):
 
         with self.recorder.use_cassette("TestComment.test_delete"):
             comment_create = self.moco.Comment.create(
-                project.id, 
-                CommentTargetType.PROJECT, 
-                "dummy comment ,test delete"
+                commentable_id=project.id,
+                commentable_type=CommentTargetType.PROJECT,
+                text="TestActivity.test_delete_create"
             )
 
-            comment_delete = self.moco.Comment.delete(comment_create.data.id)
+            comment_delete = self.moco.Comment.delete(
+                comment_id=comment_create.data.id
+            )
 
             assert comment_delete.response.status_code == 204
 
-            assert isinstance(comment_delete, EmptyResponse)
-            
\ No newline at end of file
+            assert type(comment_delete) is EmptyResponse
