@@ -1,6 +1,6 @@
 from .. import IntegrationTest
 
-from moco_wrapper.util.response import JsonResponse
+from moco_wrapper.util.response import ObjectResponse
 from moco_wrapper.models.company import CompanyType
 
 
@@ -9,7 +9,7 @@ class TestHourlyRate(IntegrationTest):
     def get_customer(self):
         with self.recorder.use_cassette("TestHourlyRate.get_company"):
             company_create = self.moco.Company.create(
-                name="test hourly rate",
+                name="TestHourlyRate.get_customer",
                 company_type=CompanyType.CUSTOMER
             )
 
@@ -19,11 +19,13 @@ class TestHourlyRate(IntegrationTest):
         customer = self.get_customer()
 
         with self.recorder.use_cassette("TestHourlyRate.test_get"):
-            hourly_rate_get = self.moco.HourlyRate.get(customer.id)
+            hourly_rate_get = self.moco.HourlyRate.get(
+                company_id=customer.id
+            )
 
             assert hourly_rate_get.response.status_code == 200
 
-            assert isinstance(hourly_rate_get, JsonResponse)
+            assert type(hourly_rate_get) is ObjectResponse
 
             assert hourly_rate_get.data.users is not None
             assert hourly_rate_get.data.tasks is not None
