@@ -1,35 +1,37 @@
-from moco_wrapper.util.response import ListingResponse, JsonResponse, EmptyResponse
+from moco_wrapper.util.response import PagedListResponse, ObjectResponse, EmptyResponse
 from moco_wrapper.models.project_recurring_expense import ProjectRecurringExpensePeriod
+from moco_wrapper.models.company import CompanyType
 
 from datetime import date
 from .. import IntegrationTest
 
+
 class TestProjectRecurringExpense(IntegrationTest):
     def get_customer(self):
         with self.recorder.use_cassette("TestProjectRecurringExpense.get_customer"):
             customer_create = self.moco.Company.create(
-                "TestProjectRecurringExpense",
-                company_type="customer"
+                name="TestProjectRecurringExpense.get_customer",
+                company_type=CompanyType.CUSTOMER
             )
 
             return customer_create.data
-    
+
     def get_user(self):
         with self.recorder.use_cassette("TestProjectRecurringExpense.get_user"):
             user = self.moco.User.getlist().items[0]
             return user
-    
+
     def get_project(self):
         user = self.get_user()
         customer = self.get_customer()
 
         with self.recorder.use_cassette("TestProjectRecurringExpense.get_project"):
             project_create = self.moco.Project.create(
-                "dummy project, test recurring expense",
-                "EUR",
-                user.id,
-                customer.id,
-                finish_date = date(2020, 1, 1)
+                name="TestProjectRecurringExpense.get_project",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
+                finish_date=date(2020, 1, 1)
             )
 
             return project_create.data
@@ -38,11 +40,13 @@ class TestProjectRecurringExpense(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_getlist"):
-            recexp_list = self.moco.ProjectRecurringExpense.getlist(project.id)
+            recexp_list = self.moco.ProjectRecurringExpense.getlist(
+                project_id=project.id
+            )
 
             assert recexp_list.response.status_code == 200
-            
-            assert isinstance(recexp_list, ListingResponse)
+
+            assert type(recexp_list) is PagedListResponse
 
             assert recexp_list.current_page == 1
             assert recexp_list.is_last is not None
@@ -56,28 +60,28 @@ class TestProjectRecurringExpense(IntegrationTest):
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_create"):
             start_date = date(2020, 1, 1)
             period = ProjectRecurringExpensePeriod.BIWEEKLY
-            title = "hosting xs - special support"
+            title = "TestProjectRecurringExpense.test_create"
             quantity = 1.5
             unit = "h"
             unit_price = 32.5
             unit_cost = 20.5
 
             recexp_create = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                start_date,
-                period,
-                title,
-                quantity,
-                unit,
-                unit_price,
-                unit_cost,
+                project_id=project.id,
+                start_date=start_date,
+                period=period,
+                title=title,
+                quantity=quantity,
+                unit=unit,
+                unit_price=unit_price,
+                unit_cost=unit_cost,
             )
 
             assert recexp_create.response.status_code == 200
 
-            assert isinstance(recexp_create, JsonResponse)
+            assert type(recexp_create) is ObjectResponse
 
-            assert recexp_create.data.start_date == start_date.isoformat() 
+            assert recexp_create.data.start_date == start_date.isoformat()
             assert recexp_create.data.period == period
             assert recexp_create.data.quantity == quantity
             assert recexp_create.data.unit == unit
@@ -90,7 +94,7 @@ class TestProjectRecurringExpense(IntegrationTest):
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_create_full"):
             start_date = date(2020, 1, 1)
             period = ProjectRecurringExpensePeriod.BIWEEKLY
-            title = "hosting xs - special support"
+            title = "TestProjectRecurringExpense.test_create_full"
             quantity = 1.5
             unit = "h"
             unit_price = 32.5
@@ -100,16 +104,15 @@ class TestProjectRecurringExpense(IntegrationTest):
             billable = False
             budget_relevant = True
 
-
             recexp_create = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                start_date,
-                period,
-                title,
-                quantity,
-                unit,
-                unit_price,
-                unit_cost,
+                project_id=project.id,
+                start_date=start_date,
+                period=period,
+                title=title,
+                quantity=quantity,
+                unit=unit,
+                unit_price=unit_price,
+                unit_cost=unit_cost,
                 finish_date=finish_date,
                 description=description,
                 billable=billable,
@@ -118,9 +121,9 @@ class TestProjectRecurringExpense(IntegrationTest):
 
             assert recexp_create.response.status_code == 200
 
-            assert isinstance(recexp_create, JsonResponse)
+            assert type(recexp_create) is ObjectResponse
 
-            assert recexp_create.data.start_date == start_date.isoformat() 
+            assert recexp_create.data.start_date == start_date.isoformat()
             assert recexp_create.data.period == period
             assert recexp_create.data.quantity == quantity
             assert recexp_create.data.unit == unit
@@ -137,7 +140,7 @@ class TestProjectRecurringExpense(IntegrationTest):
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_update"):
             start_date = date(2020, 1, 1)
             period = ProjectRecurringExpensePeriod.BIWEEKLY
-            title = "hosting xs - special support"
+            title = "TestProjectRecurringExpense.test_update"
             quantity = 1.5
             unit = "h"
             unit_price = 32.5
@@ -148,19 +151,19 @@ class TestProjectRecurringExpense(IntegrationTest):
             budget_relevant = True
 
             recexp_create = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                start_date,
-                period,
-                "dummy recurring expense, test update",
-                1,
-                "h",
-                2,
-                1
+                project_id=project.id,
+                start_date=start_date,
+                period=period,
+                title="TestProjectRecurringExpense.test_update_create",
+                quantity=1,
+                unit="h",
+                unit_price=2,
+                unit_cost=1
             )
 
             recexp_update = self.moco.ProjectRecurringExpense.update(
-                project.id,
-                recexp_create.data.id,
+                project_id=project.id,
+                recurring_expense_id=recexp_create.data.id,
                 title=title,
                 quantity=quantity,
                 unit=unit,
@@ -175,10 +178,10 @@ class TestProjectRecurringExpense(IntegrationTest):
             assert recexp_create.response.status_code == 200
             assert recexp_update.response.status_code == 200
 
-            assert isinstance(recexp_create, JsonResponse)
-            assert isinstance(recexp_update, JsonResponse)
+            assert type(recexp_create) is ObjectResponse
+            assert type(recexp_update) is ObjectResponse
 
-            assert recexp_update.data.start_date == start_date.isoformat() 
+            assert recexp_update.data.start_date == start_date.isoformat()
             assert recexp_update.data.period == period
             assert recexp_update.data.quantity == quantity
             assert recexp_update.data.unit == unit
@@ -196,39 +199,39 @@ class TestProjectRecurringExpense(IntegrationTest):
             finish_date = date(2021, 1, 1)
 
             recexp_create_with_finish = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                date(2020, 1, 1),
-                ProjectRecurringExpensePeriod.WEEKLY,
-                "dummy recurring expense, test delete finish date",
-                1,
-                "h",
-                2,
-                1,
+                project_id=project.id,
+                start_date=date(2020, 1, 1),
+                period=ProjectRecurringExpensePeriod.WEEKLY,
+                title="TestProjectRecurringExpense.test_delete_finish_date_create",
+                quantity=1,
+                unit="h",
+                unit_price=2,
+                unit_cost=1,
                 finish_date=finish_date
             )
 
             recexp_update_delete_finish = self.moco.ProjectRecurringExpense.update(
-                project.id,
-                recexp_create_with_finish.data.id,
+                project_id=project.id,
+                recurring_expense_id=recexp_create_with_finish.data.id,
                 finish_date=""
             )
 
             assert recexp_create_with_finish.response.status_code == 200
             assert recexp_update_delete_finish.response.status_code == 200
 
-            assert isinstance(recexp_create_with_finish, JsonResponse)
-            assert isinstance(recexp_update_delete_finish, JsonResponse)
+            assert type(recexp_create_with_finish) is ObjectResponse
+            assert type(recexp_update_delete_finish) is ObjectResponse
 
             assert recexp_create_with_finish.data.finish_date == finish_date.isoformat()
             assert recexp_update_delete_finish.data.finish_date is None
-    
+
     def test_get(self):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_get"):
             start_date = date(2020, 1, 1)
             period = ProjectRecurringExpensePeriod.BIWEEKLY
-            title = "hosting xs - special support"
+            title = "TestProjectRecurringExpense.test_get_create"
             quantity = 1.5
             unit = "h"
             unit_price = 32.5
@@ -238,16 +241,15 @@ class TestProjectRecurringExpense(IntegrationTest):
             billable = False
             budget_relevant = True
 
-
             recexp_create = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                start_date,
-                period,
-                title,
-                quantity,
-                unit,
-                unit_price,
-                unit_cost,
+                project_id=project.id,
+                start_date=start_date,
+                period=period,
+                title=title,
+                quantity=quantity,
+                unit=unit,
+                unit_price=unit_price,
+                unit_cost=unit_cost,
                 finish_date=finish_date,
                 description=description,
                 billable=billable,
@@ -255,17 +257,17 @@ class TestProjectRecurringExpense(IntegrationTest):
             )
 
             recexp_get = self.moco.ProjectRecurringExpense.get(
-                project.id,
-                recexp_create.data.id
+                project_id=project.id,
+                recurring_expense_id=recexp_create.data.id
             )
 
             assert recexp_create.response.status_code == 200
             assert recexp_get.response.status_code == 200
 
-            assert isinstance(recexp_create, JsonResponse)
-            assert isinstance(recexp_get, JsonResponse)
+            assert type(recexp_create) is ObjectResponse
+            assert type(recexp_get) is ObjectResponse
 
-            assert recexp_get.data.start_date == start_date.isoformat() 
+            assert recexp_get.data.start_date == start_date.isoformat()
             assert recexp_get.data.period == period
             assert recexp_get.data.quantity == quantity
             assert recexp_get.data.unit == unit
@@ -281,23 +283,22 @@ class TestProjectRecurringExpense(IntegrationTest):
 
         with self.recorder.use_cassette("TestProjectRecurringExpense.test_delete"):
             recexp_create = self.moco.ProjectRecurringExpense.create(
-                project.id,
-                date(2020, 1, 1),
-                ProjectRecurringExpensePeriod.WEEKLY,
-                "dummy recurring expense, test delete",
-                1,
-                "h",
-                2,
-                1,
+                project_id=project.id,
+                start_date=date(2020, 1, 1),
+                period=ProjectRecurringExpensePeriod.WEEKLY,
+                title="TestProjectRecurringExpense.test_delete_create",
+                quantity=1,
+                unit="h",
+                unit_price=2,
+                unit_cost=1,
             )
 
             recexp_delete = self.moco.ProjectRecurringExpense.delete(
-                project.id,
-                recexp_create.data.id,
+                project_id=project.id,
+                recurring_expense_id=recexp_create.data.id,
             )
 
             assert recexp_create.response.status_code == 200
             assert recexp_delete.response.status_code == 204
 
-            assert isinstance(recexp_delete, EmptyResponse)
-            
\ No newline at end of file
+            assert type(recexp_delete) is EmptyResponse
