@@ -1,18 +1,19 @@
 from datetime import date
 from .. import IntegrationTest
 
-from moco_wrapper.util.response import JsonResponse, EmptyResponse, ListingResponse
+from moco_wrapper.util.response import ObjectResponse, EmptyResponse, PagedListResponse
+from moco_wrapper.models.company import CompanyType
 
 class TestProjectTask(IntegrationTest):
     def get_customer(self):
         with self.recorder.use_cassette("TestProjectTask.get_customer"):
             customer_create = self.moco.Company.create(
-                "TestProjectTask",
-                company_type="customer"
+                name="TestProjectTask.get_customer",
+                company_type=CompanyType.CUSTOMER
             )
 
             return customer_create.data
-    
+
     def get_user(self):
         with self.recorder.use_cassette("TestProjectTask.get_user"):
             user = self.moco.User.getlist().items[0]
@@ -24,10 +25,10 @@ class TestProjectTask(IntegrationTest):
 
         with self.recorder.use_cassette("TestProjectTask.get_project"):
             project_create = self.moco.Project.create(
-                "dummy project, test project_task",
-                "EUR",
-                user.id,
-                customer.id,
+                name="TestProjectTask.get_project",
+                currency="EUR",
+                leader_id=user.id,
+                customer_id=customer.id,
                 finish_date=date(2020, 1, 1),
             )
 
@@ -37,15 +38,15 @@ class TestProjectTask(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectTask.test_get"):
-            name = "dummy task, test get"
+            name = "TestProjectTask.test_get_create"
             billable = False
             active = True
             budget = 500
             hourly_rate = 20
 
             task_create = self.moco.ProjectTask.create(
-                project.id,
-                name,
+                project_id=project.id,
+                name=name,
                 billable=billable,
                 active=active,
                 budget=budget,
@@ -53,15 +54,15 @@ class TestProjectTask(IntegrationTest):
             )
 
             task_get = self.moco.ProjectTask.get(
-                project.id, 
-                task_create.data.id
+                project_id=project.id,
+                task_id=task_create.data.id
             )
 
             assert task_create.response.status_code == 200
             assert task_get.response.status_code == 200
 
-            assert isinstance(task_create, JsonResponse)
-            assert isinstance(task_get, JsonResponse)
+            assert type(task_create) is ObjectResponse
+            assert type(task_get) is ObjectResponse
 
             assert task_get.data.name == name
             assert task_get.data.billable == billable
@@ -73,11 +74,13 @@ class TestProjectTask(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectTask.test_getlist"):
-            task_list = self.moco.ProjectTask.getlist(project.id)
+            task_list = self.moco.ProjectTask.getlist(
+                project_id=project.id
+            )
 
             assert task_list.response.status_code == 200
 
-            assert isinstance(task_list, ListingResponse)
+            assert type(task_list) is PagedListResponse
 
             assert task_list.current_page == 1
             assert task_list.is_last is not None
@@ -89,16 +92,16 @@ class TestProjectTask(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectTask.test_create"):
-            name = "dummy task, test create"
+            name = "TestProjectTask.test_create"
 
             task_create = self.moco.ProjectTask.create(
-                project.id,
-                name
+                project_id=project.id,
+                name=name
             )
-            
+
             assert task_create.response.status_code == 200
 
-            assert isinstance(task_create, JsonResponse)
+            assert type(task_create) is ObjectResponse
 
             assert task_create.data.name == name
 
@@ -106,15 +109,15 @@ class TestProjectTask(IntegrationTest):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectTask.test_create_full"):
-            name = "dummy task, test create full"
+            name = "TestProjectTask.test_create_full"
             billable = False
             active = True
             budget = 500
             hourly_rate = 20
 
             task_create = self.moco.ProjectTask.create(
-                project.id,
-                name,
+                project_id=project.id,
+                name=name,
                 billable=billable,
                 active=active,
                 budget=budget,
@@ -122,9 +125,9 @@ class TestProjectTask(IntegrationTest):
             )
 
             assert task_create.response.status_code == 200
-          
-            assert isinstance(task_create, JsonResponse)
-          
+
+            assert type(task_create) is ObjectResponse
+
             assert task_create.data.name == name
             assert task_create.data.billable == billable
             assert task_create.data.active == active
@@ -136,39 +139,38 @@ class TestProjectTask(IntegrationTest):
 
         with self.recorder.use_cassette("TestProjectTask.test_delete"):
             task_create = self.moco.ProjectTask.create(
-                project.id,
-                "dummy task, test delete"
+                project_id=project.id,
+                name="TestProjectTask.test_delete_create"
             )
 
             task_delete = self.moco.ProjectTask.delete(
-                project.id,
-                task_create.data.id,
+                project_id=project.id,
+                task_id=task_create.data.id,
             )
 
             assert task_create.response.status_code == 200
             assert task_delete.response.status_code == 204
 
-            assert isinstance(task_delete, EmptyResponse)
-
+            assert type(task_delete) is EmptyResponse
 
     def test_update(self):
         project = self.get_project()
 
         with self.recorder.use_cassette("TestProjectTask.test_update"):
-            name = "dummy task, this task was successfully updated"
+            name = "TestProjectTask.test_update"
             billable = False
             active = True
             budget = 500
             hourly_rate = 20
 
             task_create = self.moco.ProjectTask.create(
-                project.id,
-                "dummy task, test update"
+                project_id=project.id,
+                name="TestProjectTask.test_update_create"
             )
 
             task_update = self.moco.ProjectTask.update(
-                project.id,
-                task_create.data.id,
+                project_id=project.id,
+                task_id=task_create.data.id,
                 name=name,
                 billable=billable,
                 active=active,
@@ -178,13 +180,12 @@ class TestProjectTask(IntegrationTest):
 
             assert task_create.response.status_code == 200
             assert task_update.response.status_code == 200
-          
-            assert isinstance(task_create, JsonResponse)
-            assert isinstance(task_update, JsonResponse)
-          
+
+            assert type(task_create) is ObjectResponse
+            assert type(task_update) is ObjectResponse
+
             assert task_update.data.name == name
             assert task_update.data.billable == billable
             assert task_update.data.active == active
             assert task_update.data.budget == budget
             assert task_update.data.hourly_rate == hourly_rate
-            
\ No newline at end of file
