@@ -1,8 +1,8 @@
 from .. import IntegrationTest
 
-from moco_wrapper.util.response import JsonResponse, ListingResponse, EmptyResponse
+from moco_wrapper.util.response import ObjectResponse, PagedListResponse, EmptyResponse
 from datetime import date
-import random
+
 
 class TestUserPresence(IntegrationTest):
     def get_user(self):
@@ -20,11 +20,11 @@ class TestUserPresence(IntegrationTest):
 
         with self.recorder.use_cassette("TestUserPresence.get_other_user"):
             user_create = self.moco.User.create(
-                "test",
-                "impersonate",
-                "{}@mycompany.com".format(self.id_generator()),
-                self.id_generator(),
-                unit.id
+                firstname="-",
+                lastname="TestUserPresence.get_other_user",
+                email="{}@example.org".format(self.id_generator()),
+                password=self.id_generator(),
+                unit_id=unit.id
             )
 
             return user_create.data
@@ -32,15 +32,19 @@ class TestUserPresence(IntegrationTest):
     def test_create(self):
         with self.recorder.use_cassette("TestUserPresence.test_create"):
             pre_date = self.create_random_date()
-            from_time  = "08:30"
+            from_time = "08:30"
             to_time = "10:30"
 
-            pre_create = self.moco.UserPresence.create(pre_date, from_time, to_time)
+            pre_create = self.moco.UserPresence.create(
+                pres_date=pre_date,
+                from_time=from_time,
+                to_time=to_time
+            )
 
             assert pre_create.response.status_code == 200
-            
-            assert isinstance(pre_create, JsonResponse)
-            
+
+            assert type(pre_create) is ObjectResponse
+
             assert pre_create.data.date is not None
             assert pre_create.data.from_time == from_time
             assert pre_create.data.to_time == to_time
@@ -49,18 +53,25 @@ class TestUserPresence(IntegrationTest):
     def test_get(self):
         with self.recorder.use_cassette("TestUserPresence.test_get"):
             pre_date = self.create_random_date()
-            from_time  = "08:30"
+            from_time = "08:30"
             to_time = "10:30"
 
-            pre_create = self.moco.UserPresence.create(pre_date, from_time, to_time)
-            pre_get = self.moco.UserPresence.get(pre_create.data.id)
+            pre_create = self.moco.UserPresence.create(
+                pres_date=pre_date,
+                from_time=from_time,
+                to_time=to_time
+            )
+
+            pre_get = self.moco.UserPresence.get(
+                pres_id=pre_create.data.id
+            )
 
             assert pre_create.response.status_code == 200
             assert pre_get.response.status_code == 200
 
-            assert isinstance(pre_create, JsonResponse)
-            assert isinstance(pre_get, JsonResponse)
-            
+            assert type(pre_create) is ObjectResponse
+            assert type(pre_get) is ObjectResponse
+
             assert pre_get.data.date is not None
             assert pre_get.data.from_time == from_time
             assert pre_get.data.to_time == to_time
@@ -78,7 +89,7 @@ class TestUserPresence(IntegrationTest):
 
             assert pre_list.response.status_code == 200
 
-            assert isinstance(pre_list, ListingResponse)
+            assert type(pre_list) is PagedListResponse
 
             assert pre_list.current_page == 1
             assert pre_list.is_last is not None
@@ -89,9 +100,9 @@ class TestUserPresence(IntegrationTest):
     def test_update(self):
         with self.recorder.use_cassette("TestUserPresence.test_update"):
             pre_create = self.moco.UserPresence.create(
-                self.create_random_date(),
-                "10:30",
-                "14:00"
+                pres_date=self.create_random_date(),
+                from_time="10:30",
+                to_time="14:00"
             )
 
             pre_date = self.create_random_date()
@@ -99,7 +110,7 @@ class TestUserPresence(IntegrationTest):
             to_time = "09:30"
 
             pre_update = self.moco.UserPresence.update(
-                pre_create.data.id,
+                pres_id=pre_create.data.id,
                 pres_date=pre_date,
                 from_time=from_time,
                 to_time=to_time,
@@ -108,59 +119,61 @@ class TestUserPresence(IntegrationTest):
             assert pre_create.response.status_code == 200
             assert pre_update.response.status_code == 200
 
-            assert isinstance(pre_create, JsonResponse)
-            assert isinstance(pre_update, JsonResponse)
+            assert type(pre_create) is ObjectResponse
+            assert type(pre_update) is ObjectResponse
 
             assert pre_update.data.date is not None
             assert pre_update.data.from_time == from_time
             assert pre_update.data.to_time == to_time
             assert pre_create.data.user.id is not None
 
-
     def test_delete(self):
         with self.recorder.use_cassette("TestUserPresence.test_delete"):
             pre_create = self.moco.UserPresence.create(
-                self.create_random_date(),
-                "10:00",
-                "11:00"
+                pres_date=self.create_random_date(),
+                from_time="10:00",
+                to_time="11:00"
             )
 
-            pre_delete = self.moco.UserPresence.delete(pre_create.data.id)
+            pre_delete = self.moco.UserPresence.delete(
+                pres_id=pre_create.data.id
+            )
 
             assert pre_create.response.status_code == 200
             assert pre_delete.response.status_code == 204
 
-            assert isinstance(pre_create, JsonResponse)
-            assert isinstance(pre_delete, EmptyResponse)
+            assert type(pre_create) is ObjectResponse
+            assert type(pre_delete) is EmptyResponse
 
     def test_touch(self):
         with self.recorder.use_cassette("TestUserPresence.test_touch"):
             pre_touch = self.moco.UserPresence.touch()
 
-            #touch it a second time to discard it
-            pre_sec_touch = self.moco.UserPresence.touch()
+            # touch it a second time to discard it
+            self.moco.UserPresence.touch()
 
             assert pre_touch.response.status_code == 200
-            
-            assert isinstance(pre_touch, EmptyResponse)
+
+            assert type(pre_touch) is EmptyResponse
 
     def test_create_impersonate(self):
         other_user = self.get_other_user()
 
         with self.recorder.use_cassette("TestUserPresence.test_create_impersonate"):
-            self.moco.impersonate(other_user.id)
+            self.moco.impersonate(
+                user_id=other_user.id
+            )
 
             pre_create = self.moco.UserPresence.create(
-                self.create_random_date(),
-                "10:30",
-                "10:45"
+                pres_date=self.create_random_date(),
+                from_time="10:30",
+                to_time="10:45"
             )
 
             assert pre_create.response.status_code == 200
 
-            assert isinstance(pre_create, JsonResponse)
-            
+            assert type(pre_create) is ObjectResponse
+
             assert pre_create.data.user.id == other_user.id
 
             self.moco.clear_impersonation()
-            
\ No newline at end of file
