@@ -1,5 +1,3 @@
-import pytest
-
 from .. import UnitTest
 
 
@@ -8,7 +6,10 @@ class TestHourlyRate(UnitTest):
     def test_get(self):
         company_id = 2
 
-        response = self.moco.HourlyRate.get(company_id=company_id)
+        response = self.moco.HourlyRate.get(
+            company_id=company_id
+        )
+
         params = response["params"]
 
         assert params["company_id"] == company_id
