@@ -1,13 +1,12 @@
-import pytest
 from .. import UnitTest
-
 from datetime import date
 
+
 class TestUser(UnitTest):
     def test_create(self):
-        firstname = "firstname"
-        lastname = "lastname"
-        email = "email@email.com"
+        firstname = "-"
+        lastname = "TestUser.test_create"
+        email = "testuser_testcreate@example.com"
         password = self.id_generator()
         unit_id = 214
         active = True
@@ -16,13 +15,29 @@ class TestUser(UnitTest):
         mobile_phone = "2134124 + 123"
         work_phone = "3215 +23 "
         home_address = "this is my home address"
-        birthday = date(1994,10,10)
+        birthday = date(1994, 10, 10)
         custom_properties = {
             "custom_shirt": True
         }
         info = "more information"
 
-        response = self.moco.User.create(firstname, lastname, email, password, unit_id, active=active, external=external, language=language, mobile_phone=mobile_phone, work_phone=work_phone, home_address=home_address, birthday=birthday, custom_properties=custom_properties, info=info)
+        response = self.moco.User.create(
+            firstname=firstname,
+            lastname=lastname,
+            email=email,
+            password=password,
+            unit_id=unit_id,
+            active=active,
+            external=external,
+            language=language,
+            mobile_phone=mobile_phone,
+            work_phone=work_phone,
+            home_address=home_address,
+            birthday=birthday,
+            custom_properties=custom_properties,
+            info=info
+        )
+
         data = response["data"]
 
         assert data["firstname"] == firstname
@@ -32,7 +47,7 @@ class TestUser(UnitTest):
         assert data["unit_id"] == unit_id
         assert data["active"] == active
         assert data["external"] == external
-        assert data["language"] ==  "DE"
+        assert data["language"] == "DE"
         assert data["mobile_phone"] == mobile_phone
         assert data["work_phone"] == work_phone
         assert data["home_address"] == home_address
@@ -44,9 +59,9 @@ class TestUser(UnitTest):
 
     def test_update(self):
         user_id = 1234
-        firstname = "firstname"
-        lastname = "lastname"
-        email = "email@email.com"
+        firstname = "-"
+        lastname = "TestUser.test_update_create"
+        email = "testuser_test_update_create@example.com"
         password = self.id_generator()
         unit_id = 214
         active = True
@@ -61,7 +76,24 @@ class TestUser(UnitTest):
         },
         info = "more information"
 
-        response = self.moco.User.update(user_id, firstname=firstname, lastname=lastname, email=email, password=password, unit_id=unit_id, active=active, external=external, language=language, mobile_phone=mobile_phone, work_phone=work_phone, home_address=home_address, birthday=birthday, custom_properties=custom_properties, info=info)
+        response = self.moco.User.update(
+            user_id=user_id,
+            firstname=firstname,
+            lastname=lastname,
+            email=email,
+            password=password,
+            unit_id=unit_id,
+            active=active,
+            external=external,
+            language=language,
+            mobile_phone=mobile_phone,
+            work_phone=work_phone,
+            home_address=home_address,
+            birthday=birthday,
+            custom_properties=custom_properties,
+            info=info
+        )
+
         data = response["data"]
 
         assert data["firstname"] == firstname
@@ -80,34 +112,43 @@ class TestUser(UnitTest):
         assert data["info"] == info
 
         assert response["method"] == "PUT"
-    
+
     def test_get(self):
         user_id = 12334
 
-        response = self.moco.User.get(user_id)
+        response = self.moco.User.get(
+            user_id=user_id
+        )
 
         assert response["method"] == "GET"
 
     def test_getlist(self):
         include_archived = True
 
-        response = self.moco.User.getlist(include_archived=include_archived)
+        response = self.moco.User.getlist(
+            include_archived=include_archived
+        )
 
         assert response["params"]["include_archived"] == include_archived
         assert response["method"] == "GET"
 
     def test_getlist_sort_default(self):
-        sort_by = "testfield to sort by"
+        sort_by = "test field to sort by"
 
-        response = self.moco.User.getlist(sort_by=sort_by)
+        response = self.moco.User.getlist(
+            sort_by=sort_by
+        )
 
         assert response["params"]["sort_by"] == "{} asc".format(sort_by)
 
     def test_getlist_sort_overwrite(self):
-        sort_by = "testfield to sort by"
+        sort_by = "test field to sort by"
         sort_order = "desc"
 
-        response = self.moco.User.getlist(sort_by=sort_by, sort_order=sort_order)
+        response = self.moco.User.getlist(
+            sort_by=sort_by,
+            sort_order=sort_order
+        )
 
         assert response["params"]["sort_by"] == "{} {}".format(sort_by, sort_order)
 
@@ -115,18 +156,23 @@ class TestUser(UnitTest):
         page_default = 1
 
         response = self.moco.User.getlist()
+
         assert response["params"]["page"] == page_default
 
     def test_getlist_page_overwrite(self):
         page_overwrite = 22
 
-        response = self.moco.User.getlist(page=page_overwrite)
+        response = self.moco.User.getlist(
+            page=page_overwrite
+        )
+
         assert response["params"]["page"] == page_overwrite
-    
+
     def test_delete(self):
         user_id = 123
 
-        response = self.moco.User.delete(user_id)
+        response = self.moco.User.delete(
+            user_id=user_id
+        )
 
         assert response["method"] == "DELETE"
-        
\ No newline at end of file
