@@ -1,5 +1,4 @@
 from .. import UnitTest
-import pytest
 
 
 class TestUserPresence(UnitTest):
@@ -9,7 +8,12 @@ class TestUserPresence(UnitTest):
         to_date = '2020-10-10'
         user_id = 4
 
-        response = self.moco.UserPresence.getlist(from_date=from_date, to_date=to_date, user_id=user_id)
+        response = self.moco.UserPresence.getlist(
+            from_date=from_date,
+            to_date=to_date,
+            user_id=user_id
+        )
+
         params = response["params"]
 
         assert params["from"] == from_date
@@ -17,11 +21,12 @@ class TestUserPresence(UnitTest):
         assert params["user_id"] == user_id
         assert response["method"] == "GET"
 
-
     def test_getlist_sort_default(self):
         sort_by = "test field to sort by"
 
-        response = self.moco.UserPresence.getlist(sort_by=sort_by)
+        response = self.moco.UserPresence.getlist(
+            sort_by=sort_by
+        )
 
         assert response["params"]["sort_by"] == "{} asc".format(sort_by)
 
@@ -29,7 +34,10 @@ class TestUserPresence(UnitTest):
         sort_by = "test field to sort by"
         sort_order = "desc"
 
-        response = self.moco.UserPresence.getlist(sort_by=sort_by, sort_order=sort_order)
+        response = self.moco.UserPresence.getlist(
+            sort_by=sort_by,
+            sort_order=sort_order
+        )
 
         assert response["params"]["sort_by"] == "{} {}".format(sort_by, sort_order)
 
@@ -37,19 +45,24 @@ class TestUserPresence(UnitTest):
         page_default = 1
 
         response = self.moco.UserPresence.getlist()
+
         assert response["params"]["page"] == page_default
 
     def test_getlist_page_overwrite(self):
         page_overwrite = 22
 
-        response = self.moco.UserPresence.getlist(page=page_overwrite)
-        assert response["params"]["page"] == page_overwrite
+        response = self.moco.UserPresence.getlist(
+            page=page_overwrite
+        )
 
+        assert response["params"]["page"] == page_overwrite
 
     def test_get(self):
         presence_id = 123
 
-        response = self.moco.UserPresence.get(presence_id)
+        response = self.moco.UserPresence.get(
+            pres_id=presence_id
+        )
 
         assert response["method"] == "GET"
 
@@ -58,7 +71,12 @@ class TestUserPresence(UnitTest):
         from_time = '08:00'
         to_time = '14:00'
 
-        response = self.moco.UserPresence.create(date, from_time, to_time=to_time)
+        response = self.moco.UserPresence.create(
+            pres_date=date,
+            from_time=from_time,
+            to_time=to_time
+        )
+
         data = response["data"]
 
         assert data["date"] == date
@@ -67,18 +85,23 @@ class TestUserPresence(UnitTest):
         assert response["method"] == "POST"
 
     def test_touch(self):
-        
         response = self.moco.UserPresence.touch()
 
         assert response["method"] == "POST"
-    
+
     def test_update(self):
         presence_id = 123
         date = '2019-10-10'
         from_time = '08:00'
         to_time = '14:00'
 
-        response = self.moco.UserPresence.update(presence_id, pres_date=date, to_time=to_time, from_time=from_time)
+        response = self.moco.UserPresence.update(
+            pres_id=presence_id,
+            pres_date=date,
+            to_time=to_time,
+            from_time=from_time
+        )
+
         data = response["data"]
 
         assert data["date"] == date
@@ -86,11 +109,11 @@ class TestUserPresence(UnitTest):
         assert data["to"] == to_time
         assert response["method"] == "PUT"
 
-
     def test_delete(self):
         presence_id = 123
 
-        response = self.moco.UserPresence.delete(presence_id)
+        response = self.moco.UserPresence.delete(
+            pres_id=presence_id
+        )
 
         assert response["method"] == "DELETE"
-        
\ No newline at end of file
