@@ -6,6 +6,7 @@ from moco_wrapper import moco
 from moco_wrapper.util.requestor import RawRequestor
 from moco_wrapper.util.objector import RawObjector
 
+
 class UnitTest(object):
     def setup(self):
         self.setup_moco()
@@ -13,9 +14,9 @@ class UnitTest(object):
     def setup_moco(self):
         """create a moco instance where no requests will be fired against the api"""
         self._moco = moco.Moco(
-            auth = {
-                "api_key" : "<TOKEN>",
-                "domain" : "<DOMAIN>"
+            auth={
+                "api_key": "<TOKEN>",
+                "domain": "<DOMAIN>"
             },
             requestor=RawRequestor(),
             objector=RawObjector()
@@ -25,10 +26,6 @@ class UnitTest(object):
     def moco(self):
         return self._moco
 
-    @property
-    def requestor(self):
-        return self._moco._requestor
-
     def id_generator(self, size=6, chars=string.ascii_uppercase + string.digits):
         """
         create a random string
